@@ -1,10 +1,10 @@
---- ckuus5.c.orig	Fri Nov 14 10:20:20 2003
-+++ ckuus5.c	Fri Nov 14 16:06:56 2003
-@@ -814,6 +814,7 @@
+--- ckuus5.c.orig	2011-09-08 08:32:20.000000000 -0500
++++ ckuus5.c	2011-09-08 08:33:05.000000000 -0500
+@@ -840,6 +840,7 @@
  char * k_info_dir = NULL;               /* Where to find text files */
  #ifdef UNIX
  static char * txtdir[] = {
-+    "@@prefix@@/share/kermit"		/* Mac OS X MacPorts*/
++    "@@prefix@@/share/kermit"           /* Mac OS X MacPorts */
      "/usr/local/doc/",                  /* Linux, SunOS, ... */
      "/usr/share/lib/",                  /* HP-UX 10.xx... */
      "/usr/share/doc/",                  /* Other possibilities... */
